@@ -1,7 +1,9 @@
-/* $Id: Command.cpp 38 2007-05-01 11:14:38Z dezperado $ */
+/* $Id: Command.cpp 115 2008-01-31 16:39:52Z dezperado $ */
 /*
  Command.cpp :
 
+ (c) 2007 Michele Martone
+
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -14,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #include "fim.h"
